Protocol definitions for Hedgehog
=================================

This project contains protocol definitions for the Hedgehog Educational Robotics Controller.
Protocol implementations can pull in the contained model definitions and generate code from it.

